#!/bin/bash
#-----------------------------------------------------------------------------
#
# Author: (c) 2021 - Invoca Systems <simon.matter@invoca.ch>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 2 of the license or, at your
# option, any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#-----------------------------------------------------------------------------
#
# Usage: rotatelogs.sh [-d]
#
#   -d   Turn on debug mode, which means that no changes are made to the logs
#
#-----------------------------------------------------------------------------

declare VERSION="1.0.1"

# Treat unset variables and parameters other than the special
# parameters `@' and `*' as an error when performing parameter expansion
set -o nounset

declare Z_PROG="bzip2"
declare Z_SUFFIX="bz2"
declare OUT_SUFFIX="out"
declare ALL_SUFFIX="???"
declare DATE_FORMAT="????-??-??"

declare TODAY
TODAY="$(date "+%F")"
declare YESTERDAY
YESTERDAY="$(date --date=yesterday "+%F")"

declare LOG_FILE
declare LOG_DIR="/var/log/tomcat"
declare LOG_FORMAT="*.${DATE_FORMAT}.${ALL_SUFFIX}"
declare LOG_YESTERDAY="*.${YESTERDAY}.${ALL_SUFFIX}"
declare -i MAX_DAYS=0
declare LOGROTATE="/etc/logrotate.d/tomcat"

declare NOP=""
if (( $# )); then
  if [[ "$1" == "-d" ]]; then
    NOP="echo"
  fi
fi

declare KEY
declare VAL
if [[ -r "$LOGROTATE" ]]; then
  while read -rs KEY VAL _ 2> /dev/null; do
    if [[ "$KEY" == "rotate" ]]; then
      MAX_DAYS=$VAL
      break
    fi
  done < "$LOGROTATE"
fi

# This is a work around for old logrotate not having `dateyesterday'
echo "Moving and compressing \`.${OUT_SUFFIX}' file(s) from today to yesterday:"
for LOG_FILE in "${LOG_DIR}/"*".${TODAY}.${OUT_SUFFIX}"; do
  if [[ -f "${LOG_FILE}" ]]; then
    $NOP mv -fv "${LOG_FILE}" "${LOG_FILE/.${TODAY}./.${YESTERDAY}.}"
    $NOP "$Z_PROG" -v "${LOG_FILE/.${TODAY}./.${YESTERDAY}.}"
  fi
done

echo "Removing (recent) empty log file(s):"
find "${LOG_DIR}/" \
  -name "$LOG_FORMAT" \
  -daystart \
  -mtime +0 -empty \
  -exec $NOP rm -fv "{}" \;

if (( MAX_DAYS )); then
  echo "Removing > \`${MAX_DAYS}' days old log file(s):"
  find "${LOG_DIR}/" \
    \( -name "$LOG_FORMAT" -o -name "${LOG_FORMAT}.${Z_SUFFIX}" \) \
    -daystart \
    -mtime +${MAX_DAYS} \
    -exec $NOP rm -fv "{}" \;
else
  echo "Unable to detect number of rotations, not removing old compressed log file(s)!"
fi

# Select files by mtime or file name of yesterday
echo "Compressing (recent) log file(s) with \`${Z_PROG}':"
find "${LOG_DIR}/" \
  -name "$LOG_FORMAT" \
  -daystart \
  \( -mtime +0 -o -name "$LOG_YESTERDAY" \) \
  -exec $NOP "$Z_PROG" -v "{}" \;
