%global version 9.0.105
%global rpmrelease 1

# Extract major version from Tomcat version numbers
%global majorversion %(echo %{version} | cut -d "." -f 1)

# Tomcat UID was 91 in older distributions, current UID is 53
%global uid 53

# Systemd options
%global _has_systemd %(rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  # This is usually either `common.service' or `%{_has_systemd}.service'
  %global _servicefile_postfix common.service
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

Summary: Apache Tomcat Servlet/JSP container
Name: tomcat
Epoch: 1
Version: %{version}
Release: %{rpmrelease}%{?dist}
License: Apache-2.0
Group: Networking/Daemons
URL: https://tomcat.apache.org/
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: https://downloads.apache.org/%{name}/%{name}-%{majorversion}/v%{version}/bin/apache-%{name}-%{version}.tar.gz
Source1: %{name}.%{_servicefile_postfix}
Source2: %{name}.conf
Source3: %{name}.setenv.sh
Source4: %{name}.rotatelogs.sh
Source5: %{name}.logrotate
%if %{_has_systemd}
Source6: %{name}-tmpfiles.conf
%endif
Patch0: apache-tomcat-9.0.52-access_log.patch
Patch1: apache-tomcat-9.0.52-preset_have_tty.patch
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: grep
Requires: bzip2, logrotate, procps
Requires(pre): %{_sbindir}/groupadd, %{_sbindir}/useradd
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif

%description
Tomcat is the servlet container that is used in the official Reference
Implementation for the Java Servlet and JavaServer Pages technologies.
The Java Servlet and JavaServer Pages specifications are developed by
Sun under the Java Community Process.

Tomcat is developed in an open and participatory environment and
released under the Apache Software License version 2.0. Tomcat is intended
to be a collaboration of the best-of-breed developers from around the world.

%package admin-webapps
Group: System Environment/Applications
Summary: The host-manager and manager web applications for Apache Tomcat
Requires: %{name} = %{epoch}:%{version}-%{release}

%description admin-webapps
The host-manager and manager web applications for Apache Tomcat.

%package docs-webapp
Group: Documentation
Summary: The docs web application for Apache Tomcat
Requires: %{name} = %{epoch}:%{version}-%{release}

%description docs-webapp
The docs web application for Apache Tomcat.

%package webapps
Group: System Environment/Applications
Summary: The ROOT and examples web applications for Apache Tomcat
Requires: %{name} = %{epoch}:%{version}-%{release}

%description webapps
The ROOT and examples web applications for Apache Tomcat.

%prep
%setup -qn apache-%{name}-%{version}
%{__install} -p -m 0644 %{SOURCE5} .

# Modify conf/logging.properties
%{__grep} -Eive "\.encoding = UTF-8|\.maxDays = " \
  conf/logging.properties > conf/logging.properties.$$
%{__mv} -f conf/logging.properties.$$ conf/logging.properties

# Modify conf/server.xml
%patch0 -p1 -b .access_log
%{__rm} -f conf/server.xml.*

%patch1 -p1 -b .preset_have_tty

# Remove unneeded stuff
%{__rm} -f bin/*.sh.*
%{__rm} -f bin/*.bat
%{__rm} -f bin/*.tar.gz
%{__rm} -f temp/safeToDelete.tmp

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_javadir}
%{__install} -d %{buildroot}%{_sysconfdir}/logrotate.d
%{__install} -d %{buildroot}%{_var}/log
%{__install} -d %{buildroot}%{_var}/cache/%{name}
%{__install} -d %{buildroot}%{_var}/lib/%{name}
%{__install} -d %{buildroot}%{_libexecdir}
%{__install} -d %{buildroot}%{_pidbasedir}/%{name}

%{__mkdir_p} conf/Catalina/localhost

%{__mv} -f bin %{buildroot}%{_libexecdir}/%{name}
%{__mv} -f conf %{buildroot}%{_sysconfdir}/%{name}
%{__mv} -f lib %{buildroot}%{_javadir}/%{name}
%{__mv} -f logs %{buildroot}%{_var}/log/%{name}
%{__mv} -f temp %{buildroot}%{_var}/cache/%{name}/
%{__mv} -f webapps %{buildroot}%{_var}/lib/%{name}/
%{__mv} -f work %{buildroot}%{_var}/cache/%{name}/

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%{__install} -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
%{__install} -p -m 0644 %{SOURCE6} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -p -m 0755 %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -p -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
%{__install} -p -m 0755 %{SOURCE3} %{buildroot}%{_libexecdir}/%{name}/setenv.sh
%{__install} -p -m 0755 %{SOURCE4} %{buildroot}%{_libexecdir}/%{name}/rotatelogs.sh
%{__install} -p -m 0644 %{name}.logrotate %{buildroot}%{_sysconfdir}/logrotate.d/%{name}

%{__ln_s} %{_libexecdir}/%{name} %{buildroot}%{_var}/lib/%{name}/bin
%{__ln_s} %{_sysconfdir}/%{name} %{buildroot}%{_var}/lib/%{name}/conf
%{__ln_s} %{_javadir}/%{name} %{buildroot}%{_var}/lib/%{name}/lib
%{__ln_s} %{_var}/log/%{name} %{buildroot}%{_var}/lib/%{name}/logs
%{__ln_s} %{_var}/cache/%{name}/work %{buildroot}%{_var}/lib/%{name}/work

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%pre
getent group %{name} > /dev/null || %{_sbindir}/groupadd -f -g %{uid} -r %{name} 2> /dev/null || :
getent passwd %{name} > /dev/null ||
  %{_sbindir}/useradd -c "Apache Tomcat User" -d %{_var}/lib/%{name} -g %{name} -r -s /sbin/nologin -u %{uid} %{name} 2> /dev/null || :

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%systemd_postun_with_restart %{name}.service
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%{_libexecdir}/%{name}
%attr(-,root,%{name}) %dir %{_sysconfdir}/%{name}
%attr(0775,root,%{name}) %dir %{_sysconfdir}/%{name}/Catalina
%attr(0775,root,%{name}) %dir %{_sysconfdir}/%{name}/Catalina/localhost
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/*.policy
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/*.properties
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/*.xsd
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/context.xml
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/jaspic-providers.xml
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/server.xml
%attr(-,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/web.xml
%attr(0640,root,%{name}) %config(noreplace) %{_sysconfdir}/%{name}/tomcat-users.xml
%{_javadir}/%{name}
%attr(0770,root,%{name}) %dir %{_var}/log/%{name}
%attr(0775,root,%{name}) %dir %{_var}/lib/%{name}
%attr(0775,root,%{name}) %dir %{_var}/lib/%{name}/webapps
%attr(0770,root,%{name}) %dir %{_var}/cache/%{name}
%attr(0770,root,%{name}) %{_var}/cache/%{name}/temp
%attr(0770,root,%{name}) %{_var}/cache/%{name}/work
%if %{_has_systemd}
%{_unitdir}/%{name}.service
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%else
%config %{_initrddir}/%{name}
%endif
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_var}/lib/%{name}/bin
%{_var}/lib/%{name}/conf
%{_var}/lib/%{name}/lib
%{_var}/lib/%{name}/logs
%{_var}/lib/%{name}/work
%attr(0775,root,%{name}) %dir %{_pidbasedir}/%{name}
%doc LICENSE NOTICE RELEASE-NOTES *.md

%files admin-webapps
%defattr(0664,root,%{name},0755)
%dir %{_var}/lib/%{name}/webapps/host-manager
%dir %{_var}/lib/%{name}/webapps/manager
%{_var}/lib/%{name}/webapps/host-manager/index.jsp
%{_var}/lib/%{name}/webapps/manager/index.jsp
%{_var}/lib/%{name}/webapps/manager/status.xsd
%{_var}/lib/%{name}/webapps/manager/xform.xsl
%{_var}/lib/%{name}/webapps/host-manager/css
%{_var}/lib/%{name}/webapps/manager/css
%{_var}/lib/%{name}/webapps/host-manager/images
%{_var}/lib/%{name}/webapps/manager/images
%{_var}/lib/%{name}/webapps/host-manager/META-INF
%{_var}/lib/%{name}/webapps/manager/META-INF
%dir %{_var}/lib/%{name}/webapps/host-manager/WEB-INF
%dir %{_var}/lib/%{name}/webapps/manager/WEB-INF
%{_var}/lib/%{name}/webapps/host-manager/WEB-INF/jsp
%{_var}/lib/%{name}/webapps/manager/WEB-INF/jsp
%config(noreplace) %{_var}/lib/%{name}/webapps/host-manager/WEB-INF/manager.xml
%config(noreplace) %{_var}/lib/%{name}/webapps/host-manager/WEB-INF/web.xml
%config(noreplace) %{_var}/lib/%{name}/webapps/manager/WEB-INF/web.xml

%files docs-webapp
%defattr(-,root,root,-)
%{_var}/lib/%{name}/webapps/docs

%files webapps
%defattr(0644,%{name},%{name},0755)
%{_var}/lib/%{name}/webapps/ROOT
%{_var}/lib/%{name}/webapps/examples

%changelog
* Tue May 13 2025 Simon Matter <simon.matter@invoca.ch> 9.0.105-1
- upgrade to release 9.0.105

* Thu Apr 10 2025 Simon Matter <simon.matter@invoca.ch> 9.0.104-1
- upgrade to release 9.0.104

* Thu Mar 06 2025 Simon Matter <simon.matter@invoca.ch> 9.0.102-1
- upgrade to release 9.0.102

* Mon Feb 17 2025 Simon Matter <simon.matter@invoca.ch> 9.0.100-1
- upgrade to release 9.0.100

* Tue Feb 11 2025 Simon Matter <simon.matter@invoca.ch> 9.0.99-1
- upgrade to release 9.0.99

* Sun Jan 12 2025 Simon Matter <simon.matter@invoca.ch> 9.0.98-1
- upgrade to release 9.0.98

* Tue Nov 12 2024 Simon Matter <simon.matter@invoca.ch> 9.0.97-1
- upgrade to release 9.0.97

* Tue Oct 08 2024 Simon Matter <simon.matter@invoca.ch> 9.0.96-1
- upgrade to release 9.0.96

* Tue Sep 17 2024 Simon Matter <simon.matter@invoca.ch> 9.0.95-1
- upgrade to release 9.0.95

* Wed Sep 11 2024 Simon Matter <simon.matter@invoca.ch> 9.0.94-1
- upgrade to release 9.0.94

* Tue Aug 06 2024 Simon Matter <simon.matter@invoca.ch> 9.0.93-1
- upgrade to release 9.0.93

* Mon Jul 08 2024 Simon Matter <simon.matter@invoca.ch> 9.0.91-1
- upgrade to release 9.0.91

* Wed Jun 19 2024 Simon Matter <simon.matter@invoca.ch> 9.0.90-1
- upgrade to release 9.0.90

* Wed May 08 2024 Simon Matter <simon.matter@invoca.ch> 9.0.89-1
- upgrade to release 9.0.89

* Wed Apr 17 2024 Simon Matter <simon.matter@invoca.ch> 9.0.88-1
- upgrade to release 9.0.88

* Fri Mar 15 2024 Simon Matter <simon.matter@invoca.ch> 9.0.87-1
- upgrade to release 9.0.87

* Mon Feb 19 2024 Simon Matter <simon.matter@invoca.ch> 9.0.86-1
- upgrade to release 9.0.86

* Wed Jan 10 2024 Simon Matter <simon.matter@invoca.ch> 9.0.85-1
- upgrade to release 9.0.85

* Tue Dec 12 2023 Simon Matter <simon.matter@invoca.ch> 9.0.84-1
- upgrade to release 9.0.84

* Wed Nov 15 2023 Simon Matter <simon.matter@invoca.ch> 9.0.83-1
- upgrade to release 9.0.83

* Fri Oct 13 2023 Simon Matter <simon.matter@invoca.ch> 9.0.82-1
- upgrade to release 9.0.82

* Tue Oct 10 2023 Simon Matter <simon.matter@invoca.ch> 9.0.81-1
- upgrade to release 9.0.81

* Sat Aug 26 2023 Simon Matter <simon.matter@invoca.ch> 9.0.80-1
- upgrade to release 9.0.80

* Tue Aug 15 2023 Simon Matter <simon.matter@invoca.ch> 9.0.79-1
- upgrade to release 9.0.79

* Mon Jul 10 2023 Simon Matter <simon.matter@invoca.ch> 9.0.78-1
- upgrade to release 9.0.78

* Fri Jun 09 2023 Simon Matter <simon.matter@invoca.ch> 9.0.76-1
- upgrade to release 9.0.76

* Wed May 10 2023 Simon Matter <simon.matter@invoca.ch> 9.0.75-1
- upgrade to release 9.0.75

* Thu Apr 20 2023 Simon Matter <simon.matter@invoca.ch> 9.0.74-1
- upgrade to release 9.0.74

* Fri Mar 03 2023 Simon Matter <simon.matter@invoca.ch> 9.0.73-1
- upgrade to release 9.0.73

* Fri Feb 24 2023 Simon Matter <simon.matter@invoca.ch> 9.0.72-1
- upgrade to release 9.0.72

* Tue Jan 31 2023 Simon Matter <simon.matter@invoca.ch> 9.0.71-2
- do not set $JAVA_HOME in default configuration

* Fri Jan 13 2023 Simon Matter <simon.matter@invoca.ch> 9.0.71-1
- upgrade to release 9.0.71

* Thu Jan 05 2023 Simon Matter <simon.matter@invoca.ch> 9.0.70-2
- set epoch to 1 for compatibility with EPEL
- add requirement for procps

* Mon Dec 05 2022 Simon Matter <simon.matter@invoca.ch> 9.0.70-1
- upgrade to release 9.0.70

* Tue Nov 15 2022 Simon Matter <simon.matter@invoca.ch> 9.0.69-1
- upgrade to release 9.0.69

* Sat Oct 08 2022 Simon Matter <simon.matter@invoca.ch> 9.0.68-1
- upgrade to release 9.0.68

* Tue Sep 27 2022 Simon Matter <simon.matter@invoca.ch> 9.0.67-1
- upgrade to release 9.0.67

* Thu Jul 21 2022 Simon Matter <simon.matter@invoca.ch> 9.0.65-1
- upgrade to release 9.0.65

* Thu Jun 09 2022 Simon Matter <simon.matter@invoca.ch> 9.0.64-1
- upgrade to release 9.0.64

* Tue May 17 2022 Simon Matter <simon.matter@invoca.ch> 9.0.63-1
- upgrade to release 9.0.63

* Fri Apr 01 2022 Simon Matter <simon.matter@invoca.ch> 9.0.62-1
- upgrade to release 9.0.62

* Tue Mar 15 2022 Simon Matter <simon.matter@invoca.ch> 9.0.60-1
- upgrade to release 9.0.60

* Mon Feb 28 2022 Simon Matter <simon.matter@invoca.ch> 9.0.59-1
- upgrade to release 9.0.59

* Thu Jan 20 2022 Simon Matter <simon.matter@invoca.ch> 9.0.58-1
- upgrade to release 9.0.58

* Thu Jan 20 2022 Simon Matter <simon.matter@invoca.ch> 9.0.56-2
- add time to GC logs

* Wed Dec 08 2021 Simon Matter <simon.matter@invoca.ch> 9.0.56-1
- upgrade to release 9.0.56

* Wed Dec 01 2021 Simon Matter <simon.matter@invoca.ch> 9.0.55-4
- improve systemd service

* Fri Nov 19 2021 Simon Matter <simon.matter@invoca.ch> 9.0.55-3
- fix log rotation with new versions of logrotate

* Thu Nov 18 2021 Simon Matter <simon.matter@invoca.ch> 9.0.55-2
- disable JMX in default config

* Tue Nov 16 2021 Simon Matter <simon.matter@invoca.ch> 9.0.55-1
- upgrade to release 9.0.55

* Mon Nov 01 2021 Simon Matter <simon.matter@invoca.ch> 9.0.54-4
- improve log rotation script

* Fri Oct 29 2021 Simon Matter <simon.matter@invoca.ch> 9.0.54-3
- improve log directory permissions again

* Fri Oct 29 2021 Simon Matter <simon.matter@invoca.ch> 9.0.54-2
- silence init script
- relax log directory permissions

* Tue Oct 05 2021 Simon Matter <simon.matter@invoca.ch> 9.0.54-1
- upgrade to release 9.0.54

* Sat Sep 18 2021 Simon Matter <simon.matter@invoca.ch> 9.0.53-4
- fix log rotation

* Fri Sep 17 2021 Simon Matter <simon.matter@invoca.ch> 9.0.53-3
- add dependencies for log rotation

* Fri Sep 17 2021 Simon Matter <simon.matter@invoca.ch> 9.0.53-2
- improve logrotate config and script

* Wed Sep 15 2021 Simon Matter <simon.matter@invoca.ch> 9.0.53-1
- upgrade to release 9.0.53

* Mon Sep 13 2021 Simon Matter <simon.matter@invoca.ch> 9.0.52-5
- improve log rotation

* Sat Sep 11 2021 Simon Matter <simon.matter@invoca.ch> 9.0.52-4
- fix log rotation

* Fri Sep 10 2021 Simon Matter <simon.matter@invoca.ch> 9.0.52-3
- add access_log patch
- improve init script and systemd units
- add logrotate config and script

* Fri Sep 03 2021 Simon Matter <simon.matter@invoca.ch> 9.0.52-2
- improve tomcat.conf

* Mon Aug 30 2021 Simon Matter <simon.matter@invoca.ch> 9.0.52-1
- upgrade to release 9.0.52

* Sat Feb 06 2021 Simon Matter <simon.matter@invoca.ch> 9.0.43-1
- upgrade to release 9.0.43

* Tue Dec 29 2020 Simon Matter <simon.matter@invoca.ch> 9.0.41-2
- add missing vendor tags

* Thu Dec 10 2020 Simon Matter <simon.matter@invoca.ch> 9.0.41-1
- upgrade to release 9.0.41

* Thu Nov 19 2020 Simon Matter <simon.matter@invoca.ch> 9.0.40-1
- upgrade to release 9.0.40

* Thu Oct 22 2020 Simon Matter <simon.matter@invoca.ch> 9.0.39-1
- upgrade to release 9.0.39

* Thu Sep 17 2020 Simon Matter <simon.matter@invoca.ch> 9.0.38-1
- upgrade to release 9.0.38

* Wed Jul 08 2020 Simon Matter <simon.matter@invoca.ch> 9.0.37-1
- upgrade to release 9.0.37

* Tue Jun 09 2020 Simon Matter <simon.matter@invoca.ch> 9.0.36-1
- upgrade to release 9.0.36

* Wed May 13 2020 Simon Matter <simon.matter@invoca.ch> 9.0.35-1
- upgrade to release 9.0.35

* Mon May 11 2020 Simon Matter <simon.matter@invoca.ch> 9.0.34-4
- remove pid file definition from spec file

* Mon May 11 2020 Simon Matter <simon.matter@invoca.ch> 9.0.34-3
- remove sed from build requirements

* Sat May 09 2020 Simon Matter <simon.matter@invoca.ch> 9.0.34-2
- improve init script

* Fri May 08 2020 Simon Matter <simon.matter@invoca.ch> 9.0.34-1
- initial package
